==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appflow/kotlin/inputs/ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsTrendmicroArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appflow.kotlin.inputs

import com.pulumi.aws.appflow.inputs.ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsTrendmicroArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property apiSecretKey The API secret key required for API key authentication.
 */
public data class ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsTrendmicroArgs(
    public val apiSecretKey: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.appflow.inputs.ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsTrendmicroArgs> {
    override fun toJava():
        com.pulumi.aws.appflow.inputs.ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsTrendmicroArgs =
        com.pulumi.aws.appflow.inputs.ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsTrendmicroArgs.builder()
            .apiSecretKey(apiSecretKey.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsTrendmicroArgs].
 */
@PulumiTagMarker
public class ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsTrendmicroArgsBuilder
internal constructor() {
    private var apiSecretKey: Output<String>? = null

    /**
     * @param value The API secret key required for API key authentication.
     */
    @JvmName("rjsqqbduxvlmwkia")
    public suspend fun apiSecretKey(`value`: Output<String>) {
        this.apiSecretKey = value
    }

    /**
     * @param value The API secret key required for API key authentication.
     */
    @JvmName("xhkxbirgjfqsgxnp")
    public suspend fun apiSecretKey(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.apiSecretKey = mapped
    }

    internal fun build():
        ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsTrendmicroArgs =
        ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsTrendmicroArgs(
            apiSecretKey = apiSecretKey ?: throw PulumiNullFieldException("apiSecretKey"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appflow/kotlin/inputs/ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsTrendmicroArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appflow.kotlin.inputs

import com.pulumi.aws.appflow.inputs.ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsTrendmicroArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property apiSecretKey
 */
public data class ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsTrendmicroArgs(
    public val apiSecretKey: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.appflow.inputs.ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsTrendmicroArgs> {
    override fun toJava(): com.pulumi.aws.appflow.inputs.ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsTrendmicroArgs =
        com.pulumi.aws.appflow.inputs.ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsTrendmicroArgs.builder()
            .apiSecretKey(apiSecretKey.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsTrendmicroArgs].
 */
@PulumiTagMarker
public class ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsTrendmicroArgsBuilder
internal constructor() {
    private var apiSecretKey: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("chvabedqikwdmkor")
    public suspend fun apiSecretKey(`value`: Output<String>) {
        this.apiSecretKey = value
    }

    /**
     * @param value
     */
    @JvmName("ihyxmosqubrblfaa")
    public suspend fun apiSecretKey(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.apiSecretKey = mapped
    }

    internal fun build(): ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsTrendmicroArgs =
        ConnectorProfileConnectorProfileConfigConnectorProfileCredentialsTrendmicroArgs(
            apiSecretKey = apiSecretKey ?: throw PulumiNullFieldException("apiSecretKey"),
        )
}
